@@ -1,11 +1,8 @@
-#![allow(unused)]
 use mdbook::book::Book;
 use mdbook::errors;
 use mdbook::preprocess::{Preprocessor, PreprocessorContext};
 use std::result;
 
-use crate::theme::{CssFile, Item, Value};
-
 /// Generate some default static value. This macro is not public.
 macro_rules! default {
     ($idt:ident, $e1:expr) => { (CssFile::$idt, $e1) };
